<?php
add_action('admin_print_scripts', 'postsettings_admin_scripts');
add_action('admin_print_styles', 'postsettings_admin_styles');
if (!function_exists('postsettings_admin_scripts')) {
    function postsettings_admin_scripts(){
        global $post,$pagenow;

        if (current_user_can('edit_posts') && ($pagenow == 'post-new.php' || $pagenow == 'post.php')) {
            if( isset($post) ) {
                wp_localize_script( 'jquery', 'script_data', array(
                    'post_id' => $post->ID,
                    'nonce' => wp_create_nonce( 'wsblogz-ajax' ),
                    'image_ids' => get_post_meta( $post->ID, 'gallery_image_ids', true ),
                    'label_create' => __("Create Featured Gallery", "wsblogz"),
                    'label_edit' => __("Edit Featured Gallery", "wsblogz"),
                    'label_save' => __("Save Featured Gallery", "wsblogz"),
                    'label_saving' => __("Saving...", "wsblogz")
                ));
            }

            wp_register_script('post-colorpicker', THEME_DIR.'/framework/assets/js/colorpicker.js');       
            wp_register_script('post-metaboxes', THEME_DIR.'/framework/assets/js/metaboxes.js');        

            wp_enqueue_script('post-colorpicker');
            wp_enqueue_script('post-metaboxes');
        }
    }
}

if (!function_exists('postsettings_admin_styles')) {
    function postsettings_admin_styles(){
        global $pagenow;
        if (current_user_can('edit_posts') && ($pagenow == 'post-new.php' || $pagenow == 'post.php')) {
            wp_register_style('post-colorpicker', THEME_DIR.'/framework/assets/css/colorpicker.css', false, '1.00', 'screen');
            wp_register_style('post-metaboxes', THEME_DIR.'/framework/assets/css/metaboxes.css', false, '1.00', 'screen');

            wp_enqueue_style('post-colorpicker');
            wp_enqueue_style('post-metaboxes');
        }
    }
}

add_action("manage_posts_custom_column", "posttype_custom_columns");
if (!function_exists('posttype_custom_columns')) {
    function posttype_custom_columns($column) {
        global $post;
        switch ($column) {
            case "thumbnail":
                echo post_image_show() ? post_image_show(45,45) : ("<img src='".THEME_DIR."/resources/images/no-thumb.png'>");
                break;
            case "portfolio":
                echo get_the_term_list($post->ID, 'cat_portfolio', '', ', ', '');
                break;
            case "price":
                echo get_the_term_list($post->ID, 'cat_price', '', ', ', '');
                break;
            case "team":
                echo get_the_term_list($post->ID, 'cat_team', '', ', ', '');
                break;
            case "testimonial":
                echo get_the_term_list($post->ID, 'cat_testimonial', '', ', ', '');
                break;
        }
    }
}

/* * *********************** */
/* Custom post type: Portfolio */
/* * *********************** */

add_action('init', 'portfolio_register');
function portfolio_register() {
    $slug = ott_option('translate_portfolio') ? ott_option('translate_portfolio') : 'portfolio';
    $labels = array(
        'name' => $slug,
        'singular_name' => $slug,
        'add_new' => __('Add New', 'wsblogz'),
        'add_new_item' => __('Add New Portfolio', 'wsblogz'),
        'edit_item' => __('Edit Portfolio', 'wsblogz'),
        'new_item' => __('New Portfolio', 'wsblogz'),
        'all_items' => __('All Portfolios', 'wsblogz'),
        'view_item' => __('View Portfolio', 'wsblogz'),
        'search_items' => __('Search Portfolios', 'wsblogz'),
        'not_found' =>  __('No Portfolio found', 'wsblogz'),
        'not_found_in_trash' => __('No Portfolio found in Trash', 'wsblogz'),
        'menu_name' => __('Portfolios', 'wsblogz')
    );    
    $args = array(
        'labels' => $labels,
        'public' => true,
        'has_archive' => false,
        'publicly_queryable' => true,
        'exclude_from_search' => false,
        'show_ui' => true,
        'hierarchical' => false,

        'menu_icon' => THEME_DIR . '/framework/admin/assets/images/icons/slider.png',
        'rewrite' => array( 'slug' => $slug),
        'supports' => array('title', 'editor','page-attributes','thumbnail','revisions')
    );
    register_post_type('ott_portfolio', $args);
    flush_rewrite_rules();
}
$slug = ott_option('translate_portfolio') ? ott_option('translate_portfolio') : 'portfolio';
register_taxonomy("cat_portfolio", array("ott_portfolio"), array("hierarchical" => true, "label" => __("Categories", "wsblogz"), "singular_label" => __("Portfolio Category", "wsblogz"), 'rewrite' => array( 'slug' => $slug.'_cat')));

add_filter('manage_edit-ott_portfolio_columns', 'portfolio_edit_columns');
function portfolio_edit_columns($columns){	
    $columns = array(
        "cb" => "<input type=\"checkbox\" />",
        "title" => __("Portfolio Title", "wsblogz"),
        "portfolio" => __("Categories", "wsblogz"),
        "date" => __("Date", "wsblogz"),
    );
    return $columns;
}

/* * *********************** */
/* Custom post type: Pricing Table */
/* * *********************** */

add_action('init', 'price_register');
function price_register() {
    $labels = array(
        'name' => __('Pricing Tables', 'wsblogz'),
        'singular_name' => __('Price Item', 'wsblogz'),
        'add_new' => __('Add New', 'wsblogz'),
        'add_new_item' => __('Add New Item', 'wsblogz'),
        'edit_item' => __('Edit Item', 'wsblogz'),
        'new_item' => __('New Item', 'wsblogz'),
        'all_items' => __('All Tables', 'wsblogz'),
        'view_item' => __('View Price Item', 'wsblogz'),
        'search_items' => __('Search Pricing Tables', 'wsblogz'),
        'not_found' =>  __('No Tables found', 'wsblogz'),
        'not_found_in_trash' => __('No Tables in Trash', 'wsblogz'),
        'menu_name' => __('Pricing Tables', 'wsblogz')
    );    
    $args = array(
        'labels' => $labels,

        'public' => false,
        'has_archive' => false,
        'publicly_queryable' => true,
        'exclude_from_search' => true,
        'show_ui' => true,
        'hierarchical' => false,

            'menu_icon' => THEME_DIR . '/framework/admin/assets/images/icons/footer.png',
        'rewrite' => array( 'slug' => 'price'),
        'supports' => array('title', 'editor','page-attributes','revisions', 'custom-fields')
    );
    register_post_type('ott_price', $args);
    flush_rewrite_rules();
}
register_taxonomy("cat_price", array("ott_price"), array("hierarchical" => true, "label" => __("Categories", "wsblogz"), "singular_label" => __("Price Category","wsblogz"), "rewrite" => true));

add_filter('manage_edit-ott_price_columns', 'price_edit_columns');
function price_edit_columns($columns){	
    $columns = array(
        "cb" => "<input type=\"checkbox\" />",
        "title" => __("Table name", "wsblogz"),
        "price" => __("Categories", "wsblogz"),
        "date" => __("Date", "wsblogz"),
    );
    return $columns;
}

/* * *********************** */
/* Custom post type: Team */
/* * *********************** */

add_action('init', 'team_register');
function team_register() {    
    $labels = array(
        'name' => __('Member', 'wsblogz'),
        'singular_name' => __('Member', 'wsblogz'),
        'add_new' => __('Add New', 'wsblogz'),
        'add_new_item' => __('Add New Member', 'wsblogz'),
        'edit_item' => __('Edit Member', 'wsblogz'),
        'new_item' => __('New Member', 'wsblogz'),
        'all_items' => __('All Members', 'wsblogz'),
        'view_item' => __('View Member', 'wsblogz'),
        'search_items' => __('Search Member', 'wsblogz'),
        'not_found' =>  __('No member found', 'wsblogz'),
        'not_found_in_trash' => __('No member found in Trash', 'wsblogz'),
        'menu_name' => __('Team', 'wsblogz')
    );    
    $args = array(
        'labels' => $labels,
        
        'public' => false,
        'has_archive' => false,
        'publicly_queryable' => true,
        'exclude_from_search' => true,
        'show_ui' => true,
        'hierarchical' => false,
        
        'menu_icon' => THEME_DIR . '/framework/admin/assets/images/icons/team.png',
        'rewrite' => array( 'slug' => 'team'),
        'supports' => array('title','editor', 'page-attributes', 'thumbnail', 'revisions', 'custom-fields')
    );
    register_post_type('ott_team', $args);
    flush_rewrite_rules();
}
register_taxonomy("cat_team", array("ott_team"), array("hierarchical" => true, "label" => __("Categories", "wsblogz"), "singular_label" => __("Team Category", "wsblogz"), "rewrite" => true));

add_filter('manage_edit-ott_team_columns', 'team_edit_columns');
function team_edit_columns($columns){	
        $columns = array(
            "cb" => "<input type=\"checkbox\" />",
            "thumbnail" => __("Image", "wsblogz"),
            "title" => __("Name", "wsblogz"),
            "team" => __("Categories", "wsblogz"),
            "date" => __("Date", "wsblogz"),
        );
        return $columns;
}

/* * *********************** */
/* Custom post type: Testimonial */
/* * *********************** */

add_action('init', 'testimonial_register');
function testimonial_register() {    
    $labels = array(
        'name' => __('Testimonial', 'wsblogz'),
        'singular_name' => __('Testimonial', 'wsblogz'),
        'add_new' => __('Add New', 'wsblogz'),
        'add_new_item' => __('Add New Testimonial', 'wsblogz'),
        'edit_item' => __('Edit Testimonial', 'wsblogz'),
        'new_item' => __('New Testimonial', 'wsblogz'),
        'all_items' => __('All Testimonials', 'wsblogz'),
        'view_item' => __('View Testimonial', 'wsblogz'),
        'search_items' => __('Search Testimonials', 'wsblogz'),
        'not_found' =>  __('No testimonial found', 'wsblogz'),
        'not_found_in_trash' => __('No testimonial found in Trash', 'wsblogz'),
        'menu_name' => __('Testimonials', 'wsblogz')
    );    
    $args = array(
        'labels' => $labels,
        
        'public' => false,
        'has_archive' => false,
        'publicly_queryable' => true,
        'exclude_from_search' => true,
        'show_ui' => true,
        'hierarchical' => false,
        
        'menu_icon' => THEME_DIR . '/framework/admin/assets/images/icons/test.png',
        'rewrite' => array( 'slug' => 'testimonial'),
        'supports' => array('title', 'editor', 'page-attributes', 'thumbnail', 'revisions', 'custom-fields')
    );
    register_post_type('ott_testimonial', $args);
    flush_rewrite_rules();
}
register_taxonomy("cat_testimonial", array("ott_testimonial"), array("hierarchical" => true, "label" => __("Categories", "wsblogz"), "singular_label" => __("Testimonial Category", "wsblogz"), "rewrite" => true));

add_filter('manage_edit-ott_testimonial_columns', 'testimonial_edit_columns');
function testimonial_edit_columns($columns){	
        $columns = array(
            "cb" => "<input type=\"checkbox\" />",
            "title" => __("Name", "wsblogz"),
            "testimonial" => __("Categories", "wsblogz"),
            "date" => __("Date", "wsblogz"),
        );
        return $columns;
}


/* * *********************** */
/* Custom post type: Partner */
/* * *********************** */

add_action('init', 'partner_register');
function partner_register() {    
    $labels = array(
        'name' => __('Our Partners', 'wsblogz'),
        'singular_name' => __('Partner', 'wsblogz'),
        'add_new' => __('Add New', 'wsblogz'),
        'add_new_item' => __('Add New Partner', 'wsblogz'),
        'edit_item' => __('Edit Item', 'wsblogz'),
        'new_item' => __('New Item', 'wsblogz'),
        'all_items' => __('All Partners', 'wsblogz'),
        'view_item' => __('View Partner', 'wsblogz'),
        'search_items' => __('Search Partners', 'wsblogz'),
        'not_found' =>  __('No Partner found', 'wsblogz'),
        'not_found_in_trash' => __('No partner in Trash', 'wsblogz'),
        'menu_name' => __('Partners', 'wsblogz')
    );    
    $args = array(
        'labels' => $labels,
        
        'public' => false,
        'has_archive' => false,
        'publicly_queryable' => true,
        'exclude_from_search' => true,
        'show_ui' => true,
        'hierarchical' => false,
        
        'menu_icon' => THEME_DIR . '/framework/admin/assets/images/icons/client.png',
        'rewrite' => array( 'slug' => 'partner'),
        'supports' => array('title', 'page-attributes', 'thumbnail', 'revisions', 'custom-fields')
    );
    register_post_type('ott_partner', $args);
    flush_rewrite_rules();
}
register_taxonomy("cat_partner", array("ott_partner"), array("hierarchical" => true, "label" => __("Categories", "wsblogz"), "singular_label" => __("Partner Category", "wsblogz"), "rewrite" => true));

add_filter('manage_edit-ott_partner_columns', 'partner_edit_columns');
function partner_edit_columns($columns){	
        $columns = array(
            "cb" => "<input type=\"checkbox\" />",
            "thumbnail" => __("Image", "wsblogz"),
            "title" => __("Partners", "wsblogz"),
            "partner" => __("Categories", "wsblogz"),
            "date" => __("Date", "wsblogz"),
        );
        return $columns;
}

require_once ( THEME_PATH . '/framework/post-type/metaboxes.php');
require_once ( THEME_PATH . '/framework/post-type/post-options.php');   

function metabox_render($post, $metabox) {
    global $post; 
    $options = get_post_meta($post->ID, 'wsblogz_'.strtolower(THEMENAME).'_options', true);?>
        <input type="hidden" name="wsblogz_meta_box_nonce" value="<?php echo wp_create_nonce(basename(__FILE__));?>" />
        <table class="form-table ott-metaboxes">
            <tbody>
                    <?php	                              
                    foreach ($metabox['args'] as $settings) {
                        $settings['value'] = isset($options[$settings['id']]) ? $options[$settings['id']] : (isset($settings['std']) ? $settings['std'] : '');
                        call_user_func('settings_'.$settings['type'], $settings);	
                    }
                    ?>
            </tbody>
        </table>
<?php 
}

add_action('save_post', 'savePostMeta');
function savePostMeta($post_id) {
    global $ott_post_settings, $ott_page_settings,  $ott_portfolio_settings, $ott_portfolio_gallery, $ott_portfolio_video, $ott_price_settings, $ott_testimonial_settings, $ott_team_settings, $ott_partner_settings;

    $meta = 'wsblogz_'.strtolower(THEMENAME).'_options';
    
    // verify nonce
    if (!isset($_POST['wsblogz_meta_box_nonce']) || !wp_verify_nonce($_POST['wsblogz_meta_box_nonce'], basename(__FILE__))) {
            return $post_id;
    }
    
    // check autosave
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return $post_id;
    }
    // check permissions
    if ('page' == $_POST['post_type']) {
            if (!current_user_can('edit_page', $post_id)) {
                    return $post_id;
            }
    } elseif (!current_user_can('edit_post', $post_id)) {
            return $post_id;
    }
    
    if($_POST['post_type']=='post')
        $metaboxes = $ott_post_settings;
    elseif($_POST['post_type']=='page')
        $metaboxes = array_merge($ott_page_settings);
    elseif($_POST['post_type']=='ott_portfolio')
        $metaboxes = array_merge($ott_portfolio_settings,$ott_portfolio_gallery,$ott_portfolio_video);
    elseif($_POST['post_type']=='ott_team')
        $metaboxes = $ott_team_settings;
    elseif($_POST['post_type']=='ott_testimonial')
        $metaboxes = $ott_testimonial_settings; 
    elseif($_POST['post_type']=='ott_price')
        $metaboxes = $ott_price_settings; 
    elseif($_POST['post_type']=='ott_partner')
        $metaboxes = $ott_partner_settings; 
    
    if(!empty($metaboxes)) {
        $myMeta = array();

        foreach ($metaboxes as $metabox) {
            $myMeta[$metabox['id']] = isset($_POST[$metabox['id']]) ? $_POST[$metabox['id']] : "";
        }

        update_post_meta($post_id, $meta, $myMeta);        

    }
}

/* ================================================================================== */
/*      Save gallery images
/* ================================================================================== */

function wsblogz_save_images() {

	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) 
		return;
	
	if ( !isset($_POST['ids']) || !isset($_POST['nonce']) || !wp_verify_nonce( $_POST['nonce'], 'wsblogz-ajax' ) )
		return;
	
	if ( !current_user_can( 'edit_posts' ) ) return;
 
	$ids = strip_tags(rtrim($_POST['ids'], ','));
	update_post_meta($_POST['post_id'], 'gallery_image_ids', $ids);

	// update thumbs
	$thumbs = explode(',', $ids);
	$gallery_thumbs = '';
	foreach( $thumbs as $thumb ) {
		$gallery_thumbs .= '<li>' . wp_get_attachment_image( $thumb, array(32,32) ) . '</li>';
	}

	echo $gallery_thumbs;

	die();
}
add_action('wp_ajax_wsblogz_save_images', 'wsblogz_save_images');
?>